package com.takensoft.ai_lms.lms.book.web;

import com.takensoft.ai_lms.lms.book.service.Impl.BookServiceImpl;
import com.takensoft.ai_lms.lms.book.vo.BookVO;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author  : 구자현
 * @since   : 2024.07.25
 *
 * 교재 관련 Controller 클래스
 */
@RequiredArgsConstructor
@RestController
@RequestMapping("/book")
public class BookController {

    private final BookServiceImpl bookServiceImpl;

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 전체 교재 목록 출력
     */
    @GetMapping
    public List<BookVO> getAllBooks() {
        return bookServiceImpl.getAllBooks();
    }

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 책의 상세 정보
     */
    @GetMapping("/{book_id}")
    public BookVO getBookById(@PathVariable String book_id) {
        return bookServiceImpl.getBookById(book_id);
    }

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 교재 등록
     */
    @PostMapping
    public void insertBook(@RequestBody BookVO book) {
        bookServiceImpl.insertBook(book);
    }

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 교재 제목 수정
     */
    @PutMapping
    public void updateBook(@RequestBody BookVO book) {
        bookServiceImpl.updateBook(book);
    }

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 교재 삭제
     */
    @DeleteMapping("/{book_id}")
    public void deleteBook(@PathVariable String book_id) {
        bookServiceImpl.deleteBook(book_id);
    }
}